/**
    @file main.c

    @brief Main file for FT800 demo board app for FT51.
 *

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

/* INCLUDES ************************************************************************/
//#include <stdlib.h>
//#include <stdint.h>
//#include <string.h>
//#include <stdio.h>


#include "ft51.h"
#include "ft51_general_config.h"
#include "ft51_interrupts.h"

//#include "ft51_uart.h"
#include "ft51_iomux.h"

#include "registers\ft51_registers.h"
#include "registers\ft51_iocell_registers.h"
#include "registers\ft51_iomux_registers.h"

/* CONSTANTS ***********************************************************************/
/* Set up a UART 19200 baud 8N1:
   TXD  = P3.7 / DIO15
   RXD  = P3.3 / DIO11
   RTS# = P3.2 / DIO10
   CTS# = P3.4 / DIO12
*/
#define UART_TX DIO_15
#define UART_RX DIO_11
#define UART_RTSN DIO_10
#define UART_CTSN DIO_12
#define UART_BAUD (19200)
#define UART_DATA_BITS (8)
#define UART_STOP_BITS (1)
#define UART_PARITY (UART_PARITY_NONE)
//#define UART_FLOW_CTRL (UART_FLOW_RTS_CTS)
#define UART_FLOW_CTRL (UART_FLOW_NONE)
/* GLOBAL VARIABLES ****************************************************************/

/* LOCAL VARIABLES *****************************************************************/

/* MACROS **************************************************************************/

/* LOCAL FUNCTIONS / INLINES *******************************************************/
#ifdef UART
void init_uart()
{
    /* Enable the UART */
    UART_initialise();

    IOMUX_OUTPUT(UART_TX, IOMUX_OUT_UART_TXD); /* P3.7 */
    IOMUX_INPUT(UART_RX, IOMUX_IN_UART_RXD); /* P3.3 */
    IOMUX_OUTPUT(UART_RTSN, IOMUX_OUT_UART_RTS_N); /* P3.2 */
    IOMUX_INPUT(UART_CTSN, IOMUX_IN_UART_CTS_N); /* P3.4 */

    IOMUX_set_pad_config(UART_TX, IOMUX_PAD_DRIVE_CURRENT_4MA,
                            IOMUX_PAD_TRIGGER_SCHMITT,
                            IOMUX_PAD_SLEW_RATE_FAST,
                            IOMUX_PAD_PULL_NONE);
    IOMUX_set_pad_config(UART_RX, IOMUX_PAD_DRIVE_CURRENT_4MA,
                            IOMUX_PAD_TRIGGER_SCHMITT,
                            IOMUX_PAD_SLEW_RATE_FAST,
                            IOMUX_PAD_PULL_NONE);
    IOMUX_set_pad_config(UART_RTSN, IOMUX_PAD_DRIVE_CURRENT_4MA,
                            IOMUX_PAD_TRIGGER_SCHMITT,
                            IOMUX_PAD_SLEW_RATE_FAST,
                            IOMUX_PAD_PULL_NONE);
    IOMUX_set_pad_config(UART_CTSN, IOMUX_PAD_DRIVE_CURRENT_4MA,
                            IOMUX_PAD_TRIGGER_SCHMITT,
                            IOMUX_PAD_SLEW_RATE_FAST,
                            IOMUX_PAD_PULL_NONE);

    UART_set_baud_rate(UART_BAUD);
    UART_set_flow_control(UART_FLOW_CTRL);
    UART_set_data_bits(UART_DATA_BITS);
    UART_set_stop_bits(UART_STOP_BITS);
    UART_set_parity(UART_PARITY);
}
#endif

/* FUNCTIONS ***********************************************************************/
void loop();
void setup();

void main()
{

    ENABLE_INTERRUPTS;
    device_initialise();
#ifdef UART
    init_uart();
#endif

    setup();
    for(;;) loop();
}