/**
    @file ft51_spim_transceive_ints.c

    @brief SPI Master Library API transceive with interrupts function.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */
#include <stdint.h>
#include "ft51_spim.h"
#include "registers/ft51_spi_registers.h"
#include "ft51_interrupts.h"
#include "ft51_sfr.h" 
#include "ft51_io_registers.h"


void SPIM_transceive_ints(uint8_t  *src,
                          uint8_t  *dest,
                          uint16_t  length)
{
    uint8_t ints;

    while(length)
    {
        IO_REG_GENERAL_WRITE(SPI_MASTER_TX_DATA, *src++);

        do
        {
            IO_REG_GENERAL_READ(SPI_MASTER_INT, ints);
        }
        while (!(ints & MASK_SPI_TX_DONE_INT));
        IO_REG_INTERRUPTS_WRITE(SPI_MASTER_INT, ints);

        IO_REG_GENERAL_READ(SPI_MASTER_RX_DATA, *dest++);

        length--;
    }
}

void SPIM_initialise_ints(void)
{
    SPIM_RESET; // Reset to a known state
    SPIM_ENABLE; // Enable SPI Master device before any setup, not after.
    SPIM_SS_SETUP(1, 0);
}